Learn R Programming

ISAR (version 1.0.2)

dk_mem_utah: Draftkings Showdown Game (Grizzlies vs. Jazz)

Description

A dataset containing the Draftkings salary information for Game 4 of the 2021 NBA Playoffs between the Memphis Grizzlies and Utah Jazz.

Usage

dk_mem_utah

Arguments

Format

A data frame with 68 rows and 9 variables:

position

real-life roster position of the player

name_id

player name and Draftkings ID

name

player name

id

Draftkings player ID

roster_position

Draftkings roster position

salary

player salary

game_info

game information for the players

team_abbrev

player team as an abbreviation

avg_points_per_game

player average Draftkings points per game